@@ -555,6 +555,7 @@ GtkWidget *create_girl_app()
 	GtkWidget *girl_pixmap;
 
 	GtkWidget *appbar;
+	GtkWidget *progress;
 	
 	GirlData *girl_data = g_new0(GirlData, 1);
 	char *pmf;
@@ -580,12 +581,16 @@ GtkWidget *create_girl_app()
 	gtk_widget_show(girl_pixmap);
 	gtk_box_pack_start(GTK_BOX(vbox1), girl_pixmap, TRUE, TRUE, 0);
 
+	progress = gtk_progress_bar_new();
+	/* girl->progress = GTK_PROGRESS_BAR( progress ); */
+
 	appbar = gnome_appbar_new(FALSE, TRUE, FALSE);
 	gnome_app_set_statusbar(GNOME_APP(girl_app), GTK_WIDGET(appbar));
 	gnome_app_create_toolbar(GNOME_APP(girl_app), toolbar);
 
 	girl_data->pixmap = GTK_IMAGE(girl_pixmap);
 	girl_data->appbar = GNOME_APPBAR(appbar);
+	girl_data->progress = GTK_PROGRESS_BAR(progress);
 
 	gnome_appbar_push(girl_data->appbar,
 			  ("Point on the map and click \"Listen\" to listen to the station."));
