@@ -35,7 +35,7 @@
 #include "girl-listener.h"
 #include "girl-station.h"
 
-#ifdef DEBUG
+#ifdef GIRL_DEBUG
 #define MSG(x...) g_message(x)
 #else
 #define MSG(x...)
@@ -72,6 +72,10 @@ int main(int argc, char *argv[])
 			   argc, argv,
 			   GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
+#if defined(G_THREADS_ENABLED) && ! defined(G_THREADS_IMPL_NONE)
+	g_thread_init (NULL);
+#endif
+
 	girl_app = create_girl_app();
 
 	gtk_widget_show(girl_app);
@@ -584,6 +588,7 @@ void on_listen_button_clicked(GtkWidget *a, gpointer user_data)
 void on_record_button_clicked(GtkWidget *a, gpointer user_data)
 {
 	GtkWidget *dialog;
+	GPid *pid;
 
 	if (girl->selected_station_name != NULL) {
 		appbar_send_msg(_("Recording from %s in %s: %s "),
@@ -595,6 +600,11 @@ void on_record_button_clicked(GtkWidget *a, gpointer user_data)
 				girl->selected_station_name,
 				GIRL_STREAM_SHOUTCAST,
 				GIRL_STREAM_RECORD);
+		girl->selected_runners = girl_runners_new(getpid(),
+							  girl->selected_station_name,
+							  "date",
+							  "time",
+							  "girl.wav");
 	} else {
 		dialog = gtk_message_dialog_new(GTK_WINDOW(girl_app),
 						GTK_DIALOG_MODAL,
