@@ -48,12 +48,15 @@ typedef enum {
 #include "girl-runners.h"
 #include "girl-station.h"
 
-#ifdef DEBUG
+#ifdef GIRL_DEBUG
 #define MSG(x...) g_message(x)
 #else
 #define MSG(x...)
 #endif
 
+#define GIRL_RECORDING_TRUE 1
+#define GIRL_RECORDING_FALSE 0
+
 void show_error(gchar * msg);
 void appbar_send_msg(const char *a, ...);
 
@@ -85,6 +88,7 @@ void about_station(GtkWidget *, gpointer user_data);
 struct _GirlData {
 	GtkImage *pixmap;
 	GnomeAppBar *appbar;
+	GtkProgressBar *progress;
 	GirlListenerInfo *selected_listener;
 	gchar *selected_listener_uri;
 	gchar *selected_listener_name;
@@ -97,6 +101,8 @@ struct _GirlData {
 	gchar *selected_program_location;
 	gchar *selected_program_release;
 	gchar *selected_program_description;
+	GirlRunnersInfo *selected_runners;
+	gint timeout_id;
 	GirlStationInfo *selected_station;
 	gchar *selected_station_uri;
 	gchar *selected_station_name;
